pub trait InspectSender {
// Required methods
fn inspect_time_matrix<F, P>(
&self,
name: impl Into<String>,
matrix: TimeMatrix<F, P>,
) -> InspectedTimeMatrix<F::Sample>
where TimeMatrix<F, P>: 'static + TimeMatrixFold<F::Sample> + Send,
Metadata<F>: 'static + Send + Sync,
F: SerialStatistic<P>,
F::Sample: Send,
P: InterpolationKind;
fn inspect_time_matrix_with_metadata<F, P>(
&self,
name: impl Into<String>,
matrix: TimeMatrix<F, P>,
metadata: impl Into<Metadata<F>>,
) -> InspectedTimeMatrix<F::Sample>
where TimeMatrix<F, P>: 'static + TimeMatrixFold<F::Sample> + Send,
Metadata<F>: 'static + Send + Sync,
F: SerialStatistic<P>,
F::Sample: Send,
P: InterpolationKind;
fn clone_with_child(&self, name: &str) -> Self;
}Required Methods
Sourcefn inspect_time_matrix<F, P>(
&self,
name: impl Into<String>,
matrix: TimeMatrix<F, P>,
) -> InspectedTimeMatrix<F::Sample>where
TimeMatrix<F, P>: 'static + TimeMatrixFold<F::Sample> + Send,
Metadata<F>: 'static + Send + Sync,
F: SerialStatistic<P>,
F::Sample: Send,
P: InterpolationKind,
fn inspect_time_matrix<F, P>(
&self,
name: impl Into<String>,
matrix: TimeMatrix<F, P>,
) -> InspectedTimeMatrix<F::Sample>where
TimeMatrix<F, P>: 'static + TimeMatrixFold<F::Sample> + Send,
Metadata<F>: 'static + Send + Sync,
F: SerialStatistic<P>,
F::Sample: Send,
P: InterpolationKind,
Sends a TimeMatrix to the client’s inspection server.
Sourcefn inspect_time_matrix_with_metadata<F, P>(
&self,
name: impl Into<String>,
matrix: TimeMatrix<F, P>,
metadata: impl Into<Metadata<F>>,
) -> InspectedTimeMatrix<F::Sample>where
TimeMatrix<F, P>: 'static + TimeMatrixFold<F::Sample> + Send,
Metadata<F>: 'static + Send + Sync,
F: SerialStatistic<P>,
F::Sample: Send,
P: InterpolationKind,
fn inspect_time_matrix_with_metadata<F, P>(
&self,
name: impl Into<String>,
matrix: TimeMatrix<F, P>,
metadata: impl Into<Metadata<F>>,
) -> InspectedTimeMatrix<F::Sample>where
TimeMatrix<F, P>: 'static + TimeMatrixFold<F::Sample> + Send,
Metadata<F>: 'static + Send + Sync,
F: SerialStatistic<P>,
F::Sample: Send,
P: InterpolationKind,
Sends a TimeMatrix to the client’s inspection server.
This function lazily records the given TimeMatrix to Inspect. The server end
periodically interpolates the matrix and records data as needed. The returned
handle can be used to fold samples into the matrix.
Sourcefn clone_with_child(&self, name: &str) -> Self
fn clone_with_child(&self, name: &str) -> Self
Clones the client and scopes it to a child node with the given name.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.